MC-TACO is a dataset of 13k question-answer pairs that require temporal
commonsense comprehension. The dataset contains five temporal properties:

1.  duration (how long an event takes)
2.  temporal ordering (typical order of events)
3.  typical time (when an event occurs)
4.  frequency (how often an event occurs)
5.  stationarity (whether a state is maintained for a very long time or
    indefinitely)

We hope that this dataset can promote the future exploration of this particular
class of reasoning problems.
